const moment = require('moment');
const TipoCodigo = require('./TipoCodigoModule');
const GeraNovoCodigo = require('../functions/GeraNovoCodigo');

class NovoCodigoModule {
  async prxUpdaterEvento() {
    const contador = TipoCodigo['tcUpdaterEvento'];
    const result = await GeraNovoCodigo(contador, 1, 1);

    return this.Right(result.outBinds.P_SEQUENCIAL, 16);
  }

  async prxUpdaterHistorico() {
    const contador = TipoCodigo['tcUpdaterHistorico'];
    const result = await GeraNovoCodigo(contador, 1, 1);

    return this.Right(result.outBinds.P_SEQUENCIAL, 16);
  }

  async prxVenda(cdFilial, cdCaixa) {
    const contador = TipoCodigo['tcPedidoVenda'] + cdFilial + cdCaixa;
    const result = await GeraNovoCodigo(contador, 1, 1);

    return this.Right(result.outBinds.P_SEQUENCIAL, 10);
  }

  async prxMovCaixa(cdFilial, cdCaixa, dtAberCaix) {
    const formatDateTimeWithSlashes = (dateTime) => {
      return moment(dateTime).format('DD/MM/YYYY HH:mm:ss');
    };
    // prettier-ignore
    const contador = `${TipoCodigo['tcMovCaixa']}${cdFilial}${cdCaixa}${formatDateTimeWithSlashes(dtAberCaix)}`;

    const result = await GeraNovoCodigo(contador, 1, 1);

    return parseInt(result.outBinds.P_SEQUENCIAL, 10).toString().padStart(10, '0');
  }

  async prxMoviClie(cdCliente) {
    const contador = `${TipoCodigo['tcMovClie']}${cdCliente}`;
    const result = await GeraNovoCodigo(contador, 1, 1);

    return parseInt(result.outBinds.P_SEQUENCIAL, 10).toString().padStart(10, '0');
  }

  async prxMovBeneficioCons() {
    const contador = TipoCodigo['tcMovBeneficioCons'];
    const result = await GeraNovoCodigo(contador, 1, 1);

    return parseInt(result.outBinds.P_SEQUENCIAL, 10).toString().padStart(10, '0');
  }

  async prxPedidoFos(cdFilial, qtdePedidosFos) {
    const contador = `TipoCodigo['tcPedidoFos']${cdFilial}`;
    const result = await GeraNovoCodigo(contador, qtdePedidosFos, 1);

    return parseInt(result.outBinds.P_SEQUENCIAL, 10).toString().padStart(10, '0');
  }

  Right(num, size) {
    const zeros =
      '0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000';
    return (zeros + num).substr(size * -1);
  }

  Left(num, size) {
    const zeros =
      '0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000';
    return (num + zeros).substr(0, size);
  }
}

module.exports = new NovoCodigoModule();
